pub struct NearSigner { /* private fields */ }Implementations
Sourceimpl NearSigner
impl NearSigner
pub fn new( network: &NetworkConfig, account_id: &str, private_key: &str, ) -> Result<Self>
pub async fn call_contract( &self, method_name: &str, args: Value, gas: u64, deposit: u128, ) -> Result<FinalExecutionOutcomeView>
Sourcepub async fn get_tx_context(&self) -> Result<(u64, CryptoHash)>
pub async fn get_tx_context(&self) -> Result<(u64, CryptoHash)>
Get current access key nonce and latest block hash for building transactions.
Sourcepub async fn send_function_call_async(
&self,
receiver_id: &AccountId,
method_name: &str,
args: Vec<u8>,
gas: u64,
deposit: u128,
nonce: u64,
block_hash: CryptoHash,
) -> Result<CryptoHash>
pub async fn send_function_call_async( &self, receiver_id: &AccountId, method_name: &str, args: Vec<u8>, gas: u64, deposit: u128, nonce: u64, block_hash: CryptoHash, ) -> Result<CryptoHash>
Send a raw function call to an arbitrary receiver (broadcast async, does not wait). Returns the transaction hash.